/*
 * Copyright (c) 2016 Kristaps Dzonsons <kristaps@bsd.lv>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#if defined(__APPLE__)
#include <sandbox.h>
#endif
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>

int
main(void)
{
#if defined(__APPLE__)
	char	*ep;
	int	 rc;
#endif

	/*
	 * Create a sandbox that only lets us do pure computation: we
	 * don't open any more file descriptors or do anything fancy.
	 */
#if defined(__APPLE__)
	rc = sandbox_init
		(kSBXProfilePureComputation, 
		 SANDBOX_NAMED, &ep);
	if (-1 == rc) {
		fprintf(stderr, "sandbox_init: %s\n", ep);
		sandbox_free_error(ep);
		return(EXIT_FAILURE);
	}
#elif defined(__OpenBSD__)
	if (-1 == pledge("stdio", NULL)) {
		perror("pledge");
		return(EXIT_FAILURE);
	}
#endif

	puts("Status: 200 OK\r");
	puts("Content-Type: text/html\r");
	puts("\r");
	puts("Hello, world!");
	return(EXIT_SUCCESS);
}
