/*
 * Copyright (c) 2016 Kristaps Dzonsons <kristaps@bsd.lv>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#if defined(__APPLE__)
#include <sandbox.h>
#endif
#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <unistd.h>

#include <kcgi.h>

int 
main(void) 
{
	struct kreq 	 r;
	const char 	*page = "index";
#if defined(__APPLE__)
	char		*ep;
	int	 	 rc;
#endif

	if (KCGI_OK != khttp_parse(&r, NULL, 0, &page, 1, 0))
		return(EXIT_FAILURE);

	/*
	 * kcgi(3) won't do anything special with the writing routines
	 * except flush to the stream, possibly by way of zlib.
	 * Thus, enact a sandbox that allows open file descriptors but
	 * not anything more.
	 */
#if defined(__APPLE__)
	rc = sandbox_init
		(kSBXProfilePureComputation, 
		 SANDBOX_NAMED, &ep);
	if (-1 == rc) {
		fprintf(stderr, "sandbox_init: %s\n", ep);
		sandbox_free_error(ep);
		khttp_free(&r);
		return(EXIT_FAILURE);
	}
#elif defined(__OpenBSD__)
	if (-1 == pledge("stdio", NULL)) {
		perror("pledge");
		khttp_free(&r);
		return(EXIT_FAILURE);
	}
#endif

	khttp_head(&r, kresps[KRESP_STATUS], 
		"%s", khttps[KHTTP_200]);
	khttp_head(&r, kresps[KRESP_CONTENT_TYPE], 
		"%s", kmimetypes[r.mime]);
	khttp_body(&r);
	khttp_puts(&r, "Hello, world!\n");
	khttp_free(&r);
	return(EXIT_SUCCESS);
}
